// $Id: mixer.h,v 1.9 2003/03/11 17:09:37 gordon Exp $	
//
// Copyright (C) 2002 Gordon Fraser <gordon@debian.org>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// See the COPYING file for more details
//

#ifndef __mixer_h__
#define __mixer_h__

#include <cstdlib>

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <string>

#include "device.h"
#include "exception.h"
//----------------------------------------------------------------------
class Mixer
{
 protected:
  unsigned num_devices_;
  string device_name_;

  inline bool isValidChannel(unsigned channel_num) const
    {
      return channel_num < num_devices_;
    }

 public:
  Mixer();
  Mixer(const string&);
  virtual ~Mixer();
  virtual void muteChannel(unsigned) = 0;
  virtual void unMuteChannel(unsigned) = 0;
  virtual bool isMuted(unsigned) const = 0;
  virtual bool isMono(unsigned) const = 0;
  virtual bool isSupported(unsigned) const = 0;
  virtual bool isEnabled(unsigned) const = 0;
  virtual bool canCapture(unsigned) const = 0;

  virtual void setChannelLeft(unsigned, unsigned) = 0;
  virtual void setChannelRight(unsigned, unsigned) = 0;

  virtual unsigned getChannelLeft(unsigned) const = 0;
  virtual unsigned getChannelRight(unsigned) const = 0;

  virtual unsigned getNumChannels() const;
  virtual void setNumChannels(unsigned);

  virtual bool toggleChannelRecord(unsigned) = 0;

  virtual bool hasChanged() = 0;
  virtual void doUpdate() = 0;
  virtual void doUpdate(unsigned) = 0;
  virtual bool getCapture(unsigned) const = 0;

  virtual const string& getChannelName(unsigned) const = 0;
  virtual void enableChannel(unsigned) = 0;
  virtual void disableChannel(unsigned) = 0;
};

#endif //__mixer_h__
